# __init__.py
def get_ann():
    code = '''
    # Importing Packages
    import numpy as np
    import pandas as pd 
    import keras
    from keras.models import Sequential
    from keras.layers import Dense,Dropout
    from sklearn.model_selection import train_test_split
    from sklearn.preprocessing import MinMaxScaler
    import keras
    import tensorflow as tf
    import matplotlib.pyplot as plt

    # Importing Data
    df_diabetes = pd.read_csv("../input/diabetes/diabetes.csv")

    # Data Overview
    df_diabetes.head()

    # Dataset Details
    df_diabetes.describe()

    # Dataset Shape
    df_diabetes.shape

    # Independent Dependent Variables Split
    X = df_diabetes.drop("Outcome",axis = 1)
    Y = df_diabetes["Outcome"]

    # Train Test SPlit
    X_train, X_test,y_train,y_test = train_test_split(X,Y,test_size = 0.25,random_state = 27)

    # Scaling
    scaler = MinMaxScaler()
    scaled_train = scaler.fit_transform(X_train)
    scaled_test = scaler.transform(X_test)

    ## NN MODEl
    model = Sequential()
    model.add(Dense(512, activation='relu', input_shape=(X.shape[1],)))
    model.add(Dropout(0.5))
    model.add(Dense(256, activation='relu'))
    model.add(Dropout(0.25))
    model.add(Dense(1, activation='sigmoid'))

    # Compiling the model
    model.compile(optimizer = tf.keras.optimizers.Adam(learning_rate = 0.001),
                loss=keras.losses.BinaryCrossentropy(from_logits=True),
                metrics=["accuracy"])

    # Fitting train,test data in the model
    history = model.fit(X_train,y_train,epochs=100,validation_data=(X_test,y_test),batch_size = 64)

    # Model Structure Overview
    model.summary()

    # Plotting accuracy of train,test
    def plot_metric(history, metric):
        train_metrics = history.history[metric]
        val_metrics = history.history['val_'+metric]
        epochs = range(1, len(train_metrics) + 1)
        plt.plot(epochs, train_metrics)
        plt.plot(epochs, val_metrics)
        plt.title('Training and validation '+ metric)
        plt.xlabel("Epochs")
        plt.ylabel(metric)
        plt.legend(["train_"+metric, 'val_'+metric])
        plt.show()

    # Checking acccuracy graph
    plot_metric(history,"accuracy")'''
    print(code)


def get_ann_encoded():
    code = '''
    import pandas as pd
    import numpy as np
    import matplotlib.pyplot as plt
    import category_encoders as ce
    from keras.models import Sequential
    from keras.layers import Dense
    from sklearn.model_selection import train_test_split

    data=pd.read_csv("/content/drive/MyDrive/mushroom_dataset/mushrooms.csv")
    data.head()
    data.shape

    df=pd.get_dummies(data,data.columns,drop_first=True)
    X=df.drop(['class_p'],axis=1)
    y=df['class_p']

    X_train,X_test,y_train,y_test=train_test_split(X,y,test_size=0.3,random_state=0)
    X_train,X_val,y_train,y_val=train_test_split(X_train,y_train,test_size=0.3,random_state=0)
    X_train.shape

    model=Sequential()
    model.add(Dense(12,input_dim=95,activation='relu'))
    model.add(Dense(8,activation='relu'))
    model.add(Dense(1,activation='sigmoid'))
    model.compile(loss='binary_crossentropy',optimizer='adam',metrics=['accuracy'])
    model.fit(X_train,y_train,epochs=50,batch_size=10,validation_data=(X_val,y_val))
    model.summary()

    y_pred=model.predict(X_test)
    y_pred=(y_pred>0.5)
    y_pred

    from sklearn.metrics import accuracy_score,confusion_matrix
    score=accuracy_score(y_test,y_pred)
    cm=confusion_matrix(y_test,y_pred)
    print(cm)
    '''
    print(code)

def get_cnn_bw():
    code = '''
    from keras.datasets import mnist
    from keras.models import Sequential
    from keras.layers import Dense,Dropout,Conv2D,MaxPool2D,Flatten
    from keras.utils import np_utils
    import numpy as np

    (X_train,y_train),(X_test,y_test)=mnist.load_data()

    X_train.shape

    from sklearn.model_selection import train_test_split
    X_train,X_val,y_train,y_val=train_test_split(X_train,y_train,test_size=0.3,random_state=0)

    X_train=X_train.reshape(X_train.shape[0],28,28,1)
    X_test=X_test.reshape(X_test.shape[0],28,28,1)
    X_val=X_val.reshape(X_val.shape[0],28,28,1)

    X_train=X_train.astype('float32')
    X_val=X_val.astype('float32')
    X_test=X_test.astype('float32')

    X_train=X_train/255
    X_val=X_val/255
    X_test=X_test/255

    n_classes=10
    print("Shape before one-hot encoding: ",y_train.shape)
    Y_train=np_utils.to_categorical(y_train,n_classes)
    Y_val=np_utils.to_categorical(y_val,n_classes)
    Y_test=np_utils.to_categorical(y_test,n_classes)
    print("Shape after one-hot encoding: ",Y_train.shape)
    print("Shape after one-hot encoding: ",Y_val.shape)

    model=Sequential()
    model.add(Conv2D(32,kernel_size=(3,3),strides=(1,1),padding='valid',activation='relu',input_shape=X_train.shape[1:]))
    model.add(MaxPool2D(pool_size=(2,2)))
    model.add(Flatten())
    model.add(Dense(100,activation='relu'))
    model.add(Dense(10,activation='softmax'))

    model.compile(loss='categorical_crossentropy',metrics=['accuracy'],optimizer='adam')

    history=model.fit(X_train,Y_train,epochs=2,batch_size=400,validation_data=(X_val,Y_val))

    import matplotlib.pyplot as plt
    acc=history.history['accuracy']
    val_acc=history.history['val_accuracy']
    epochs=range(1,3)
    plt.plot(epochs,acc,label='accuracy')
    plt.plot(epochs,val_acc,label='Validation Accuracy')
    plt.xlabel("Epochs")
    plt.ylabel("Accuracy")
    plt.legend()
    plt.show()

    loss=history.history['loss']
    val_loss=history.history['val_loss']
    epochs=range(1,3)
    plt.plot(epochs,loss,label='loss')
    plt.plot(epochs,val_loss,label='Validation loss')
    plt.xlabel("Epochs")
    plt.ylabel("Loss")
    plt.show()

    y_pred=model.predict(X_test)
    y_pred=(y_pred>0.5)
    y_pred

    Y_pred=np.argmax((y_pred>0.5),axis=1)
    print(Y_pred)
    print(y_test)

    Y_test

    from sklearn.metrics import accuracy_score,confusion_matrix

    score=accuracy_score(Y_test,y_pred)
    score

    import seaborn as sns
    cm=confusion_matrix(y_test,Y_pred)
    sns.heatmap(cm,annot=True)
    '''
    print(code)

def get_cnn_rgb():
    code = '''
    from keras.datasets import cifar10
    from keras.layers import Dense,Flatten,MaxPool2D,Conv2D
    from keras.models import Sequential

    (X_train,y_train),(X_test,y_test)=cifar10.load_data()

    X_train.shape

    from sklearn.model_selection import train_test_split
    X_train,X_val,y_train,y_val=train_test_split(X_train,y_train,test_size=0.3,random_state=0)

    X_train=X_train.astype('float32')
    X_val=X_val.astype('float32')
    X_test=X_test.astype('float32')

    X_train=X_train/255
    X_test=X_test/255
    X_val=X_val/255

    from keras.utils import np_utils

    y_train=np_utils.to_categorical(y_train)
    y_val=np_utils.to_categorical(y_val)
    y_test=np_utils.to_categorical(y_test)

    X_train.shape

    model=Sequential()

    model.add(Conv2D(32,kernel_size=(4,4),activation='relu',input_shape=X_train.shape[1:],padding='valid'))
    model.add(MaxPool2D(pool_size=(3,3)))
    model.add(Flatten())
    model.add(Dense(64,activation='relu'))
    model.add(Dense(32,activation='relu'))
    model.add(Dense(10,activation='softmax'))

    model.compile(loss='categorical_crossentropy',optimizer='adam',metrics=['accuracy'])

    history=model.fit(X_train,y_train,epochs=2,batch_size=200,validation_data=(X_val,y_val))

    y_pred=model.predict(X_test)
    y_pred=(y_pred>0.5)
    y_pred

    y_test

    from sklearn.metrics import accuracy_score,confusion_matrix

    score=accuracy_score(y_test,y_pred)
    score

    import matplotlib.pyplot as plt

    acc=history.history['accuracy']
    val_acc=history.history['val_accuracy']
    epochs=range(1,3)
    plt.plot(epochs,acc,label="accuracy")
    plt.plot(epochs,val_acc,label='val_accuracy')
    plt.xlabel("Epochs")
    plt.ylabel("Accuracy")
    plt.legend()
    plt.show()

    train_loss=history.history['loss']
    val_loss=history.history['val_loss']
    epochs=range(1,3)
    plt.plot(epochs,train_loss,label="loss")
    plt.plot(epochs,val_loss,label='val_loss')
    plt.xlabel("Epochs")
    plt.ylabel("loss")
    plt.legend()
    plt.show()
    '''
    print(code)